@@ -33,11 +33,6 @@
 /* List of clients that are selecting events on our clients */
 static GSList* selector_list = NULL;
 
-/* If set, exec() this command on shutdown instead of exiting
- */
-static gint logout_command_argc = 0;
-static gchar **logout_command_argv = NULL;
-
 /* Counter for generating unique handles: */
 static guint handle;
 
@@ -260,13 +255,6 @@ command_active (Client* client)
 	  client->command_data->state != COMMAND_INACTIVE);
 }
 
-void
-execute_logout (void)
-{
-  if (logout_command_argv)
-    execvp (logout_command_argv[0], logout_command_argv);
-}
-
 static gint		
 cmp_args (gconstpointer a, gconstpointer b)
 {
@@ -276,23 +264,6 @@ cmp_args (gconstpointer a, gconstpointer b)
   return strcmp (arg_a, arg_b);
 }
 
-void
-set_logout_command (char **command)
-{
-  int j;
-  if (logout_command_argv)
-    {
-      for (j = 0; j < logout_command_argc; j++)
-	g_free (logout_command_argv[j]);
-      g_free (logout_command_argv);
-    }
-  for (j = 0; command[j]; ++j) /**/;
-  logout_command_argv = g_new (gchar *, j + 1);
-  for (j = 0; command[j]; ++j)
-    logout_command_argv[j] = g_strdup (command[j]);
-  logout_command_argv[j] = NULL;
-}
-
 void
 command (Client* client, int nprops, SmProp** props)
 {
